import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/*****************************************************************************
 * 
 * @author Jonathan Misurda
 * @version 1.0
 *****************************************************************************/
class ControlPanel extends JPanel {

	private JButton cmdNext = new JButton("NEXT >>");
	private JButton cmdAnswer = new JButton("Show Answer");
	private JButton cmdPrev = new JButton("<< PREV");
	private TimerControl myTC = new TimerControl(cmdNext);
	private JTextArea txtQuestion;
	private StatusPanel myStatusPanel = new StatusPanel();

	public void enableNext(boolean b) {
		cmdNext.setEnabled(b);
	}

	public ControlPanel(JTextArea txtQ) {
		setLayout(new GridLayout(1,3));

		cmdNext.setFont(QBScorerData.captionFont);
		cmdAnswer.setFont(QBScorerData.captionFont);
		cmdPrev.setFont(QBScorerData.captionFont);

		txtQuestion = txtQ;

		cmdAnswer.setEnabled(false);

		Action showAnswer = new AbstractAction() {
			public void actionPerformed(ActionEvent ke) {
				cmdAnswer.setEnabled(false);
				cmdNext.setEnabled(true);

				showAnswer();
			}
		};

		Action prevQuestion = new AbstractAction() {
			public void actionPerformed(ActionEvent ke) {
				cmdAnswer.setEnabled(true);
				cmdNext.setEnabled(true);

				prevQuestion();
				myStatusPanel.update();

			}
		};

		Action nextQuestion = new AbstractAction() {
			public void actionPerformed(ActionEvent ke) {
				cmdAnswer.setEnabled(true);
				cmdNext.setEnabled(false);

				nextQuestion();
				
				myStatusPanel.update();
			}
		};

		InputMap im = getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW);
		im.put(KeyStroke.getKeyStroke("LEFT"), "prevQuestion");
		im.put(KeyStroke.getKeyStroke("UP"), "showAnswer");
		im.put(KeyStroke.getKeyStroke("RIGHT"), "nextQuestion");
		getActionMap().put("prevQuestion",prevQuestion);
		getActionMap().put("showAnswer",showAnswer);
		getActionMap().put("nextQuestion",nextQuestion);
		
		cmdAnswer.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent ae) {
				cmdAnswer.setEnabled(false);
				cmdNext.setEnabled(true);

				showAnswer();
			}
		});

		cmdPrev.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent ae) {
				cmdAnswer.setEnabled(true);
				cmdNext.setEnabled(true);
				prevQuestion();
				myStatusPanel.update();
			}
		});

		cmdNext.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent ae) {
				cmdAnswer.setEnabled(true);
				cmdNext.setEnabled(false);

				nextQuestion();
				
				myStatusPanel.update();
			}
		});

		add(myTC);
		JPanel nextPanel = new JPanel(new FlowLayout(FlowLayout.CENTER));
		nextPanel.add(cmdNext);
		nextPanel.add(cmdAnswer);
		nextPanel.add(cmdPrev);
		add(nextPanel);
		add(myStatusPanel);
	}

	private void nextQuestion() {
		switch(QBScorerData.GamePhase) {
			case QBScorerData.TOSSUP1:
				
				txtQuestion.setText((String)QBScorerData.tossup1Questions.elementAt(QBScorerData.curQuestionInPhase));
				break;

			case QBScorerData.ALLTEAM:
				
				txtQuestion.setText((String)QBScorerData.allTeamQuestions.elementAt(QBScorerData.curQuestionInPhase));
				break;

			case QBScorerData.TOSSUP2:
				
				txtQuestion.setText((String)QBScorerData.tossup2Questions.elementAt(QBScorerData.curQuestionInPhase));
				break;

			case QBScorerData.BONUS:
				if(QBScorerData.curQuestionInPhase >= QBScorerData.bonusQuestions.size()) {
					JOptionPane.showMessageDialog(null, "NO MORE QUESTIONS!", "Out of questions", JOptionPane.WARNING_MESSAGE);
					break;
				}
				txtQuestion.setText((String)QBScorerData.bonusQuestions.elementAt(QBScorerData.curQuestionInPhase));
				break;
		}
	}

	private void showAnswer() {
		switch(QBScorerData.GamePhase) {
			case QBScorerData.TOSSUP1:
				txtQuestion.setText((String)QBScorerData.tossup1Answers.elementAt(QBScorerData.curQuestionInPhase));
				QBScorerData.TIME = QBScorerData.SHORT_TIME;
				QBScorerData.curQuestionInPhase++;
				if(QBScorerData.curQuestionInPhase >= QBScorerData.tossup1Questions.size()) {
					QBScorerData.GamePhase = QBScorerData.ALLTEAM;
					QBScorerData.curQuestionInPhase = 0;
					QBScorerData.TIME = QBScorerData.LONG_TIME;
				}
				break;

			case QBScorerData.ALLTEAM:
				txtQuestion.setText((String)QBScorerData.allTeamAnswers.elementAt(QBScorerData.curQuestionInPhase));
				QBScorerData.curQuestionInPhase++;
				if(QBScorerData.curQuestionInPhase >= QBScorerData.allTeamQuestions.size()) {
					QBScorerData.GamePhase = QBScorerData.TOSSUP2;
					QBScorerData.curQuestionInPhase = 0;
					QBScorerData.TIME = QBScorerData.SHORT_TIME;
				}
				break;

			case QBScorerData.TOSSUP2:
				txtQuestion.setText((String)QBScorerData.tossup2Answers.elementAt(QBScorerData.curQuestionInPhase));
				QBScorerData.curQuestionInPhase++;
				if(QBScorerData.curQuestionInPhase >= QBScorerData.tossup2Questions.size()) {
					QBScorerData.GamePhase = QBScorerData.BONUS;
					QBScorerData.curQuestionInPhase = 0;
					QBScorerData.TIME = QBScorerData.SHORT_TIME;
				}
				break;

			case QBScorerData.BONUS:
				if(QBScorerData.curQuestionInPhase >= QBScorerData.bonusAnswers.size()) {
					JOptionPane.showMessageDialog(null, "NO MORE QUESTIONS!", "Out of questions", JOptionPane.WARNING_MESSAGE);
					break;
				}
				txtQuestion.setText((String)QBScorerData.bonusAnswers.elementAt(QBScorerData.curQuestionInPhase));
				QBScorerData.curQuestionInPhase++;
				break;
		}
	}

	private void prevQuestion() {
		switch(QBScorerData.GamePhase) {

			case QBScorerData.TOSSUP1:
				QBScorerData.curQuestionInPhase--;
				if(QBScorerData.curQuestionInPhase < 0) {
					JOptionPane.showMessageDialog(null, "NO MORE QUESTIONS!", "Out of questions", JOptionPane.WARNING_MESSAGE);
					QBScorerData.GamePhase = QBScorerData.TOSSUP1;
					QBScorerData.curQuestionInPhase = 0;
					QBScorerData.TIME = QBScorerData.SHORT_TIME;
				}

				txtQuestion.setText((String)QBScorerData.tossup1Questions.elementAt(QBScorerData.curQuestionInPhase));
				break;

			case QBScorerData.ALLTEAM:
				QBScorerData.curQuestionInPhase--;
				if(QBScorerData.curQuestionInPhase < 0) {
					QBScorerData.GamePhase = QBScorerData.TOSSUP1;
					QBScorerData.curQuestionInPhase = QBScorerData.tossup1Questions.size()-1;
					QBScorerData.TIME = QBScorerData.SHORT_TIME;
					txtQuestion.setText((String)QBScorerData.tossup1Questions.elementAt(QBScorerData.curQuestionInPhase));
				}
				else {
					txtQuestion.setText((String)QBScorerData.allTeamQuestions.elementAt(QBScorerData.curQuestionInPhase));
					QBScorerData.TIME = QBScorerData.LONG_TIME;
				}
				break;

			case QBScorerData.TOSSUP2:
				QBScorerData.curQuestionInPhase--;
				if(QBScorerData.curQuestionInPhase < 0) {
					QBScorerData.GamePhase = QBScorerData.ALLTEAM;
					QBScorerData.curQuestionInPhase = QBScorerData.allTeamQuestions.size()-1;
					QBScorerData.TIME = QBScorerData.LONG_TIME;
					txtQuestion.setText((String)QBScorerData.allTeamQuestions.elementAt(QBScorerData.curQuestionInPhase));
				}
				else {
					txtQuestion.setText((String)QBScorerData.tossup2Questions.elementAt(QBScorerData.curQuestionInPhase));
					QBScorerData.TIME = QBScorerData.SHORT_TIME;
				}
				break;

			case QBScorerData.BONUS:
				QBScorerData.curQuestionInPhase--;
				if(QBScorerData.curQuestionInPhase < 0) {
					QBScorerData.GamePhase = QBScorerData.TOSSUP2;
					QBScorerData.curQuestionInPhase = QBScorerData.tossup2Questions.size()-1;
					QBScorerData.TIME = QBScorerData.SHORT_TIME;
					txtQuestion.setText((String)QBScorerData.tossup2Questions.elementAt(QBScorerData.curQuestionInPhase));
				}
				else {
					txtQuestion.setText((String)QBScorerData.bonusQuestions.elementAt(QBScorerData.curQuestionInPhase));
					QBScorerData.TIME = QBScorerData.SHORT_TIME;
				}
				break;
		}
	}

}

class StatusPanel extends JPanel {
	private JLabel lblCurRound = new JLabel("", JLabel.CENTER);
	private JLabel lblCurQuestion = new JLabel("", JLabel.CENTER);

	public StatusPanel() {
		setLayout(new GridLayout(2,1));

		lblCurRound.setFont(QBScorerData.captionFont);
		lblCurQuestion.setFont(QBScorerData.captionFont);

		add(lblCurRound);
		add(lblCurQuestion);

		update();
	}

	public void update() {
		switch(QBScorerData.GamePhase) {
			case QBScorerData.TOSSUP1:
				lblCurRound.setText("Tossups Round 1");
				lblCurQuestion.setText((QBScorerData.curQuestionInPhase+1) + " of " + QBScorerData.tossup1Questions.size());
				break;

			case QBScorerData.ALLTEAM:
				lblCurRound.setText("All Team Round");
				lblCurQuestion.setText((QBScorerData.curQuestionInPhase+1)+ " of " + QBScorerData.allTeamQuestions.size());
				break;

			case QBScorerData.TOSSUP2:
				lblCurRound.setText("Tossups Round 2");
				lblCurQuestion.setText((QBScorerData.curQuestionInPhase+1) + " of " + QBScorerData.tossup2Questions.size());
				break;

			case QBScorerData.BONUS:
				lblCurRound.setText("Tiebreaker Round");
				lblCurQuestion.setText((QBScorerData.curQuestionInPhase+1) + " of " + QBScorerData.bonusQuestions.size());
				break;
		}
	}

}