import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;

/*****************************************************************************
 * This is the main driver class for the program. It first creates a
 * WizardDialog (@see WizardDialog) and then it uses those setting to create 
 * the main window.
 *
 * @author Jonathan Misurda
 * @version 1.0
 *
 *****************************************************************************/
public class QBScorer extends JFrame
{
	//The array of components that display team name and score
	private ScorerPanel scorerPanels[];

	//The component to display the question text
	private JTextArea questionPanel = new JTextArea("This is where your question will be shown", 400, 10);
	
	/*************************************************************************
	 * The main method of the program - Creates the WizardDialog, then
	 * initializes the main window.
	 * 
	 * @param args - Command Line arguments to the program
	 *************************************************************************/
	public static void main(String[] args) 	{
		WizardDialog myWD = new WizardDialog();
		myWD.show();
		QBScorer myQBS = new QBScorer();
		myQBS.show();
	}

	/*************************************************************************
	 * The constructor - initializes the main window components
	 * 
	 *************************************************************************/
	public QBScorer() {
		//If the team name vector is empty, the wizard dialog must have been
		//dismissed with the X, so exit the program as expected.
		if(QBScorerData.TeamNames.size() == 0) {
			System.exit(0);
		}

		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent we) {
				System.exit(0);
			}
		});

		setTitle("QBScorer");

		JPanel myScorerPanel = new JPanel();
		ControlPanel myCP = new ControlPanel(questionPanel);

		questionPanel.setFont(QBScorerData.questionFont);

		//Make the JTextArea actually word wrap
		questionPanel.setLineWrap(true);
		questionPanel.setWrapStyleWord(true);

		questionPanel.setEnabled(false);
		questionPanel.setDisabledTextColor(Color.black);
		questionPanel.setFocusable(false);

		Container myCont = getContentPane();

		//Allow for some space between the scorer panels, the question text,
		//and the control panel at the bottom
		((BorderLayout)myCont.getLayout()).setVgap(25);

		//Make a One-by-TEAMS grid on the upper panel to hold the ScorerPanels
		GridLayout myGL = new GridLayout(1,QBScorerData.TEAMS,15,0);
		myScorerPanel.setLayout(myGL);

		//Make the array of ScorerPanels, and initialize them to the 
		//TeamNames given in the WizardDialog.
		scorerPanels = new ScorerPanel[QBScorerData.TEAMS];
		for(int i=0; i<QBScorerData.TEAMS; i++) {
			scorerPanels[i] = new ScorerPanel((String)QBScorerData.TeamNames.elementAt(i));
			myScorerPanel.add(scorerPanels[i]);
		}

		myCont.add(myScorerPanel, BorderLayout.NORTH);
		myCont.add(questionPanel, BorderLayout.CENTER);
		myCont.add(myCP, BorderLayout.SOUTH);

		//Add some blank space to the east and west
		myCont.add(new JPanel(), BorderLayout.EAST);
		myCont.add(new JPanel(), BorderLayout.WEST);

		pack();
	}
}