import java.util.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import javax.sound.sampled.*;

/*****************************************************************************
 * 
 * @author Jonathan Misurda
 * @version 1.0
 *****************************************************************************/
class TimerControl extends JPanel {
	private JButton cmdReset = new JButton("Reset");
	private JButton cmdStart = new JButton("Start");
	private JButton cmdStop = new JButton("Stop");
	private JLabel lblTimer = new JLabel(String.valueOf(QBScorerData.TIME), SwingConstants.CENTER);
	private JLabel lblTitle = new JLabel("Timer", SwingConstants.CENTER);
	
	private TimerThread tt = new TimerThread();

	private AudioInputStream myAIS;
	private Clip clip;

	public int time = QBScorerData.TIME;

	private JButton cmdNext;

	public TimerControl(JButton button) {
		try
		{
			myAIS = AudioSystem.getAudioInputStream(new File("buzzer.au"));
			AudioFormat format = myAIS.getFormat();
			AudioFormat tmp = new AudioFormat(
				AudioFormat.Encoding.PCM_SIGNED, 
				format.getSampleRate(),
				format.getSampleSizeInBits() * 2,
				format.getChannels(),
				format.getFrameSize() * 2,
				format.getFrameRate(),
				true);
			myAIS = AudioSystem.getAudioInputStream(tmp, myAIS);
			format = tmp;
			
			DataLine.Info info = new DataLine.Info(
				Clip.class, 
				myAIS.getFormat(), 
				((int) myAIS.getFrameLength() *
				format.getFrameSize()));

			clip = (Clip) AudioSystem.getLine(info);
			clip.open(myAIS);
		}
		catch (Exception e) {
			System.out.println(e);
		}
	
		setLayout(new BorderLayout());
		add(lblTimer, BorderLayout.CENTER);

		cmdNext = button;
	
		JPanel myButtonPanel = new JPanel();

		lblTimer.setFont(QBScorerData.bigFont);
		lblTimer.setForeground(Color.red);

		lblTitle.setFont(QBScorerData.captionFont);
		lblTitle.setForeground(Color.blue);

		add(lblTitle, BorderLayout.NORTH);

		cmdStart.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent ae) {
				tt.start();
			}
		});

		Action startTimer = new AbstractAction() {
			public void actionPerformed(ActionEvent ke) {
				tt.start();
			}
		};

		Action stopTimer = new AbstractAction() {
			public void actionPerformed(ActionEvent ke) {
				tt.stop();
			}
		};

		Action resetTimer = new AbstractAction() {
			public void actionPerformed(ActionEvent ke) {
				time = QBScorerData.TIME;
				lblTimer.setText(String.valueOf(time));
				tt = new TimerThread();
				cmdStart.setEnabled(true);
			}
		};

		InputMap im = getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW);
		im.put(KeyStroke.getKeyStroke("F1"), "startTimer");
		im.put(KeyStroke.getKeyStroke("F2"), "stopTimer");
		im.put(KeyStroke.getKeyStroke("F3"), "resetTimer");
		getActionMap().put("startTimer",startTimer);
		getActionMap().put("stopTimer",stopTimer);
		getActionMap().put("resetTimer",resetTimer);
		
		cmdStop.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent ae) {
				tt.stop();
			}
		});

		cmdReset.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent ae) {
				time = QBScorerData.TIME;
				lblTimer.setText(String.valueOf(time));
				tt = new TimerThread();
				cmdStart.setEnabled(true);
			}
		});

		myButtonPanel.add(cmdStart);
		myButtonPanel.add(cmdStop);
		myButtonPanel.add(cmdReset);

		add(myButtonPanel, BorderLayout.SOUTH);
	}

	class TimerThread extends Thread {
		public void run() {
			//cmdNext.setEnabled(false);
			try {
				while(time > 0) {
					Thread.sleep(1000);
					time--;
					lblTimer.setText(String.valueOf(time));
				}
				clip.setMicrosecondPosition(0);
				clip.start();
				cmdStart.setEnabled(false);
			} catch (InterruptedException ie) {}
		}
	}
}
