import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;
import org.xml.sax.*;
import org.xml.sax.helpers.DefaultHandler;
import javax.xml.parsers.SAXParserFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;

/*****************************************************************************
 * 
 * @author Jonathan Misurda
 * @version 1.0
 *****************************************************************************/
class WizardDialog extends JDialog {
	private String filename;
	private int numTeams;

	private JLabel lblFile = new JLabel("Question File:", SwingConstants.RIGHT);
	private JTextField txtFilename = new JTextField(30);
	private JButton cmdBrowse = new JButton("Browse");

	private JLabel lblBigFont = new JLabel("Big Font Size:", SwingConstants.RIGHT);
	private JComboBox cmbBigTextSize = new JComboBox(new String[] {"144","96","72","48", "36", "24"});

	private JLabel lblCaptionFont = new JLabel("Caption Font Size:", SwingConstants.RIGHT);
	private JComboBox cmbCaptionTextSize = new JComboBox(new String[] {"72","48", "36", "24", "18"});

	private JLabel lblQuestionFont = new JLabel("Question Font Size:", SwingConstants.RIGHT);
	private JComboBox cmbQuestionTextSize = new JComboBox(new String[] {"96", "72","48", "36", "24", "18"});

	private JLabel lblNumTeams = new JLabel("Number of Teams:", SwingConstants.RIGHT);
	private JComboBox cmbNumTeams = new JComboBox(new String[] {"1","2", "3", "4", "5"});

	private JLabel lblCorrectPoints = new JLabel("Points for Correct Answer:", SwingConstants.RIGHT);
	private JSpinner spnCorrectPoints = new JSpinner();

	private JLabel lblIncorrectPoints = new JLabel("Points for Incorrect Answer:", SwingConstants.RIGHT);
	private JSpinner spnIncorrectPoints = new JSpinner();

	private JLabel lblShortTime = new JLabel("Time for Tossups:", SwingConstants.RIGHT);
	private JSpinner spnShortTime = new JSpinner();

	private JLabel lblLongTime = new JLabel("Time for All-team:", SwingConstants.RIGHT);
	private JSpinner spnLongTime = new JSpinner();

	private JButton cmdGo = new JButton("Go");

	public WizardDialog() {
		setModal(true);
		setTitle("Setup wizard");

		lblFile.setLabelFor(txtFilename);
		lblBigFont.setLabelFor(cmbBigTextSize);
		lblCaptionFont.setLabelFor(cmbCaptionTextSize);
		lblQuestionFont.setLabelFor(cmbQuestionTextSize);
		lblNumTeams.setLabelFor(cmbNumTeams);
		lblCorrectPoints.setLabelFor(spnCorrectPoints);
		lblIncorrectPoints.setLabelFor(spnIncorrectPoints);
		lblShortTime.setLabelFor(spnShortTime);
		lblLongTime.setLabelFor(spnLongTime);

		spnCorrectPoints.setValue(new Integer(20));
		spnIncorrectPoints.setValue(new Integer(-20));

		spnShortTime.setValue(new Integer(3));
		spnLongTime.setValue(new Integer(30));

		cmbBigTextSize.setSelectedItem("72");
		cmbCaptionTextSize.setSelectedItem("24");
		cmbQuestionTextSize.setSelectedItem("36");
		cmbNumTeams.setSelectedItem("3");

		Container myCP = getContentPane();
		myCP.setLayout(new GridLayout(6,1,50,50));

		JPanel panel1 = new JPanel();
		panel1.add(lblFile);
		panel1.add(txtFilename);
		panel1.add(cmdBrowse);
		myCP.add(panel1);

		JPanel panel2 = new JPanel();
		panel2.add(lblBigFont);
		panel2.add(cmbBigTextSize);

		panel2.add(lblCaptionFont);
		panel2.add(cmbCaptionTextSize);

		panel2.add(lblQuestionFont);
		panel2.add(cmbQuestionTextSize);
		myCP.add(panel2);

		JPanel panel3 = new JPanel();
		panel3.add(lblNumTeams);
		panel3.add(cmbNumTeams);
		myCP.add(panel3);

		JPanel panel4 = new JPanel();
		panel4.add(lblCorrectPoints);
		panel4.add(spnCorrectPoints);
		panel4.add(lblIncorrectPoints);
		panel4.add(spnIncorrectPoints);
		myCP.add(panel4);

		JPanel panel5 = new JPanel();
		panel5.add(lblShortTime);
		panel5.add(spnShortTime);
		panel5.add(lblLongTime);
		panel5.add(spnLongTime);
		myCP.add(panel5);

		JPanel panel6 = new JPanel();
		panel6.add(cmdGo);
		myCP.add(panel6);

		pack();

		cmdBrowse.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent ae) {
				JFileChooser chooser = new JFileChooser();
				int returnVal = chooser.showOpenDialog(WizardDialog.this);
				if(returnVal == JFileChooser.APPROVE_OPTION) {
				   txtFilename.setText(chooser.getSelectedFile().getName());
				}
			}
		});

		cmdGo.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent ae) {
				filename = txtFilename.getText();

				QBScorerData.bigFont = new Font("Arial", Font.BOLD, Integer.parseInt((String)cmbBigTextSize.getSelectedItem()));
				QBScorerData.captionFont = new Font("Arial", Font.BOLD, Integer.parseInt((String)cmbCaptionTextSize.getSelectedItem()));
				QBScorerData.questionFont = new Font("Arial", Font.BOLD, Integer.parseInt((String)cmbQuestionTextSize.getSelectedItem()));

				QBScorerData.TEAMS = cmbNumTeams.getSelectedIndex() + 1;

				QBScorerData.CORRECT_POINTS = ((Integer)spnCorrectPoints.getValue()).intValue();
				QBScorerData.WRONG_POINTS = ((Integer)spnIncorrectPoints.getValue()).intValue();

				QBScorerData.TIME = QBScorerData.SHORT_TIME = ((Integer)spnShortTime.getValue()).intValue();
				QBScorerData.LONG_TIME = ((Integer)spnLongTime.getValue()).intValue();

				try
				{
					SAXParserFactory factory = SAXParserFactory.newInstance();
					SAXParser saxParser = factory.newSAXParser();
					DefaultHandler handler = new QuestionHandler();;
					saxParser.parse(new File(filename), handler);
				}
				catch (Exception e)
				{
					System.out.println(e);
					JOptionPane.showMessageDialog(WizardDialog.this,"There was an error loading the xml file " + filename);
					System.exit(1);
				}

				for(int i=0;i<QBScorerData.TEAMS; i++) {
					QBScorerData.TeamNames.add(JOptionPane.showInputDialog(WizardDialog.this, "Enter Team " + (i+1) + "'s name:"));
				}

				dispose();
			}
		});
	}
}

/*****************************************************************************
 * 
 *
 *****************************************************************************/
class QuestionHandler extends DefaultHandler {

	private boolean inQuestionBody = false;
	private boolean inQuestionAnswer = false;

	private int gameSection = -1;

	private StringBuffer bodyText;
	private StringBuffer ansText;
  
	public void startElement(String namespaceURI, String localName,	String qualifiedName, Attributes atts) throws SAXException {
		if(qualifiedName.equals("tossup1")) {
			gameSection = QBScorerData.TOSSUP1;
		}
		else if(qualifiedName.equals("allteam")) {
			gameSection = QBScorerData.ALLTEAM;
		}
		else if(qualifiedName.equals("tossup2")) {
			gameSection = QBScorerData.TOSSUP2;
		}
		else if(qualifiedName.equals("bonustossup")) {
			gameSection = QBScorerData.BONUS;
		}
		else if(qualifiedName.equals("body")) {
			inQuestionBody = true;
			bodyText = new StringBuffer();
		}
		else if(qualifiedName.equals("ans")) {
			inQuestionAnswer = true;
			ansText = new StringBuffer();
		}
	}

	public void endElement(String namespaceURI, String localName, String qualifiedName) throws SAXException {
		if(qualifiedName.equals("body")) {
			String bText = bodyText.toString().trim();
			switch(gameSection) {
				case QBScorerData.TOSSUP1:
								QBScorerData.tossup1Questions.add(bText);
								break;
				case QBScorerData.ALLTEAM:
								QBScorerData.allTeamQuestions.add(bText);
								break;
				case QBScorerData.TOSSUP2:
								QBScorerData.tossup2Questions.add(bText);
								break;
				case QBScorerData.BONUS:
								QBScorerData.bonusQuestions.add(bText);
								break;
			}

			inQuestionBody = false;
		}
		else if(qualifiedName.equals("ans")) {
			String aText = ansText.toString().trim();
			switch(gameSection) {
				case QBScorerData.TOSSUP1:
								QBScorerData.tossup1Answers.add(aText);
								break;
				case QBScorerData.ALLTEAM:
								QBScorerData.allTeamAnswers.add(aText);
								break;
				case QBScorerData.TOSSUP2:
								QBScorerData.tossup2Answers.add(aText);
								break;
				case QBScorerData.BONUS:
								QBScorerData.bonusAnswers.add(aText);
								break;
			}

			inQuestionBody = false;
		}
	}

	public void characters(char[] ch, int start, int length) throws SAXException {
		if(inQuestionBody) {
			String s = new String(ch, start, length);
			bodyText.append(s);
		}
		else if(inQuestionAnswer) {
			String s = new String(ch, start, length);
			ansText.append(s);
		}
	}
  
}